@@ -1,7 +1,7 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
@@ -62,6 +62,41 @@
 #define SYS_NAME_ID_x86_darwin_80        509
 #define SYS_NAME_ID_ppc_darwin_90        510
 #define SYS_NAME_ID_x86_darwin_90        511
+#define SYS_NAME_ID_ppc_darwin_100       512
+#define SYS_NAME_ID_ppc64_darwin_100     513
+#define SYS_NAME_ID_x86_darwin_100       514
+#define SYS_NAME_ID_amd64_darwin_100     515
+#define SYS_NAME_ID_arm_darwin_100       516
+#define SYS_NAME_ID_x86_darwin_110       517
+#define SYS_NAME_ID_amd64_darwin_110     518
+#define SYS_NAME_ID_arm_darwin_110       519
+#define SYS_NAME_ID_x86_darwin_120       520
+#define SYS_NAME_ID_amd64_darwin_120     521
+#define SYS_NAME_ID_arm_darwin_120       522
+#define SYS_NAME_ID_x86_darwin_130       523
+#define SYS_NAME_ID_amd64_darwin_130     524
+#define SYS_NAME_ID_arm_darwin_130       525
+#define SYS_NAME_ID_x86_darwin_140       526
+#define SYS_NAME_ID_amd64_darwin_140     527
+#define SYS_NAME_ID_arm_darwin_140       528
+#define SYS_NAME_ID_x86_darwin_150       529
+#define SYS_NAME_ID_amd64_darwin_150     530
+#define SYS_NAME_ID_arm_darwin_150       531
+#define SYS_NAME_ID_x86_darwin_160       532
+#define SYS_NAME_ID_amd64_darwin_160     533
+#define SYS_NAME_ID_arm_darwin_160       534
+#define SYS_NAME_ID_x86_darwin_170       535
+#define SYS_NAME_ID_amd64_darwin_170     536
+#define SYS_NAME_ID_arm_darwin_170       537
+#define SYS_NAME_ID_x86_darwin_180       538
+#define SYS_NAME_ID_amd64_darwin_180     539
+#define SYS_NAME_ID_arm_darwin_180       540
+#define SYS_NAME_ID_x86_darwin_190       541
+#define SYS_NAME_ID_amd64_darwin_190     542
+#define SYS_NAME_ID_arm_darwin_190       543
+#define SYS_NAME_ID_x86_darwin_200       544
+#define SYS_NAME_ID_amd64_darwin_200     545
+#define SYS_NAME_ID_arm_darwin_200       546
 
 #define SYS_NAME_ID_next_mach20		 601
 #define SYS_NAME_ID_next_mach30		 602
@@ -73,6 +108,7 @@
 #define SYS_NAME_ID_rs_aix43		 705
 #define SYS_NAME_ID_rs_aix52		 706
 #define SYS_NAME_ID_rs_aix53		 707
+#define SYS_NAME_ID_rs_aix61		 708
 
 #define SYS_NAME_ID_sun3_411		 906
 #define SYS_NAME_ID_sun3x_411		 912
@@ -152,6 +188,7 @@
 #define SYS_NAME_ID_sparc_linux2	1700
 #define SYS_NAME_ID_sparc_linux22	1701
 #define SYS_NAME_ID_sparc_linux24	1702
+#define SYS_NAME_ID_sparc_linux26	1703
 
 #define SYS_NAME_ID_sparc64_linux2	1800
 #define SYS_NAME_ID_sparc64_linux22	1801
@@ -184,6 +221,33 @@
 #define SYS_NAME_ID_i386_fbsd_53        2108
 #define SYS_NAME_ID_i386_fbsd_60        2112
 #define SYS_NAME_ID_i386_fbsd_61        2113
+#define SYS_NAME_ID_i386_fbsd_62        2114
+#define SYS_NAME_ID_i386_fbsd_70        2115
+#define SYS_NAME_ID_i386_fbsd_71        2116
+#define SYS_NAME_ID_i386_fbsd_72        2130
+#define SYS_NAME_ID_i386_fbsd_73        2131
+#define SYS_NAME_ID_i386_fbsd_74        2132
+#define SYS_NAME_ID_i386_fbsd_80        2117
+#define SYS_NAME_ID_i386_fbsd_81        2118
+#define SYS_NAME_ID_i386_fbsd_82        2119
+#define SYS_NAME_ID_i386_fbsd_83        2121
+#define SYS_NAME_ID_i386_fbsd_84        2123
+#define SYS_NAME_ID_i386_fbsd_90        2120
+#define SYS_NAME_ID_i386_fbsd_91        2122
+#define SYS_NAME_ID_i386_fbsd_92        2124
+#define SYS_NAME_ID_i386_fbsd_93        2126
+#define SYS_NAME_ID_i386_fbsd_100      2150
+#define SYS_NAME_ID_i386_fbsd_101      2151
+#define SYS_NAME_ID_i386_fbsd_102      2152
+#define SYS_NAME_ID_i386_fbsd_103      2153
+#define SYS_NAME_ID_i386_fbsd_104      2154
+#define SYS_NAME_ID_i386_fbsd_110      2140
+#define SYS_NAME_ID_i386_fbsd_111      2141
+#define SYS_NAME_ID_i386_fbsd_112      2142
+#define SYS_NAME_ID_i386_fbsd_113      2143
+#define SYS_NAME_ID_i386_fbsd_120      2160
+#define SYS_NAME_ID_i386_fbsd_121      2161
+#define SYS_NAME_ID_i386_fbsd_122      2162
 
 #define SYS_NAME_ID_ia64_linux2		2200
 #define SYS_NAME_ID_ia64_linux22	2201
@@ -201,34 +265,44 @@
 #define SYS_NAME_ID_sparc_nbsd15        2503
 #define SYS_NAME_ID_sparc64_nbsd15      2504
 
-#define SYS_NAME_ID_i386_nbsd16		2510
-#define SYS_NAME_ID_alpha_nbsd16	2511
-#define SYS_NAME_ID_sparc_nbsd16	2512
-#define SYS_NAME_ID_sparc64_nbsd16	2513
-#define SYS_NAME_ID_macppc_nbsd16	2514
+#define SYS_NAME_ID_i386_nbsd16         2510
+#define SYS_NAME_ID_alpha_nbsd16        2511
+#define SYS_NAME_ID_sparc_nbsd16        2512
+#define SYS_NAME_ID_sparc64_nbsd16      2513
+#define SYS_NAME_ID_macppc_nbsd16       2514
 
-#define SYS_NAME_ID_i386_nbsd20		2520
-#define SYS_NAME_ID_alpha_nbsd20	2521
-#define SYS_NAME_ID_sparc_nbsd20	2522
-#define SYS_NAME_ID_sparc64_nbsd20	2523
-#define SYS_NAME_ID_macppc_nbsd20	2524
-#define SYS_NAME_ID_i386_nbsd21		2525
-#define SYS_NAME_ID_i386_nbsd30		2526
-#define SYS_NAME_ID_amd64_nbsd20	2527
-#define SYS_NAME_ID_i386_nbsd40 2528
-#define SYS_NAME_ID_i386_nbsd50 2529
-#define SYS_NAME_ID_sparc64_nbsd30 2530
-#define SYS_NAME_ID_sparc64_nbsd40 2531
-#define SYS_NAME_ID_sparc64_nbsd50 2532
-#define SYS_NAME_ID_amd64_nbsd30 2533
-#define SYS_NAME_ID_amd64_nbsd40 2534
-#define SYS_NAME_ID_amd64_nbsd50 2535
-#define SYS_NAME_ID_alpha_nbsd30 2536
-#define SYS_NAME_ID_alpha_nbsd40 2537
-#define SYS_NAME_ID_alpha_nbsd50 2538
-#define SYS_NAME_ID_macppc_nbsd30 2539
-#define SYS_NAME_ID_macppc_nbsd40 2540
-#define SYS_NAME_ID_macppc_nbsd50 2541
+#define SYS_NAME_ID_i386_nbsd20         2520
+#define SYS_NAME_ID_alpha_nbsd20        2521
+#define SYS_NAME_ID_sparc_nbsd20        2522
+#define SYS_NAME_ID_sparc64_nbsd20      2523
+#define SYS_NAME_ID_macppc_nbsd20       2524
+#define SYS_NAME_ID_i386_nbsd21         2525
+#define SYS_NAME_ID_i386_nbsd30         2526
+#define SYS_NAME_ID_amd64_nbsd20        2527
+#define SYS_NAME_ID_i386_nbsd40         2528
+#define SYS_NAME_ID_i386_nbsd50         2529
+#define SYS_NAME_ID_sparc64_nbsd30      2530
+#define SYS_NAME_ID_sparc64_nbsd40      2531
+#define SYS_NAME_ID_sparc64_nbsd50      2532
+#define SYS_NAME_ID_amd64_nbsd30        2533
+#define SYS_NAME_ID_amd64_nbsd40        2534
+#define SYS_NAME_ID_amd64_nbsd50        2535
+#define SYS_NAME_ID_alpha_nbsd30        2536
+#define SYS_NAME_ID_alpha_nbsd40        2537
+#define SYS_NAME_ID_alpha_nbsd50        2538
+#define SYS_NAME_ID_macppc_nbsd30       2539
+#define SYS_NAME_ID_macppc_nbsd40       2540
+#define SYS_NAME_ID_macppc_nbsd50       2541
+#define SYS_NAME_ID_amd64_nbsd60        2542
+#define SYS_NAME_ID_i386_nbsd60         2543
+#define SYS_NAME_ID_amd64_nbsd70        2544
+#define SYS_NAME_ID_i386_nbsd70         2545
+#define SYS_NAME_ID_amd64_nbsd80        2546
+#define SYS_NAME_ID_arm32_nbsd80        2547
+#define SYS_NAME_ID_i386_nbsd80         2548
+#define SYS_NAME_ID_amd64_nbsd90        2549
+#define SYS_NAME_ID_i386_nbsd90         2550
+#define SYS_NAME_ID_macppc_nbsd100      2551
 
 #define SYS_NAME_ID_i386_obsd31		2600
 #define SYS_NAME_ID_i386_obsd32		2601
@@ -252,6 +326,8 @@
 #define SYS_NAME_ID_i386_obsd50         2619
 #define SYS_NAME_ID_i386_obsd51         2620
 #define SYS_NAME_ID_i386_obsd52         2621
+#define SYS_NAME_ID_i386_obsd53         2622
+#define SYS_NAME_ID_i386_obsd54         2623
 
 #define SYS_NAME_ID_amd64_linux2        2700
 #define SYS_NAME_ID_amd64_linux22       2701
@@ -268,7 +344,33 @@
 #define SYS_NAME_ID_ppc64_linux24	2902
 #define SYS_NAME_ID_ppc64_linux26	2903
 
-#define SYS_NAME_ID_amd64_fbsd_53        3008
+#define SYS_NAME_ID_amd64_fbsd_53       3008
+#define SYS_NAME_ID_amd64_fbsd_70       3009
+#define SYS_NAME_ID_amd64_fbsd_71       3010
+#define SYS_NAME_ID_amd64_fbsd_72       3030
+#define SYS_NAME_ID_amd64_fbsd_73       3031
+#define SYS_NAME_ID_amd64_fbsd_74       3032
+#define SYS_NAME_ID_amd64_fbsd_80       3011
+#define SYS_NAME_ID_amd64_fbsd_81       3012
+#define SYS_NAME_ID_amd64_fbsd_82       3013
+#define SYS_NAME_ID_amd64_fbsd_83       3014
+#define SYS_NAME_ID_amd64_fbsd_84       3015
+#define SYS_NAME_ID_amd64_fbsd_90       3020
+#define SYS_NAME_ID_amd64_fbsd_91       3022
+#define SYS_NAME_ID_amd64_fbsd_92       3023
+#define SYS_NAME_ID_amd64_fbsd_93       3024
+#define SYS_NAME_ID_amd64_fbsd_100     3050
+#define SYS_NAME_ID_amd64_fbsd_101     3051
+#define SYS_NAME_ID_amd64_fbsd_102     3052
+#define SYS_NAME_ID_amd64_fbsd_103     3053
+#define SYS_NAME_ID_amd64_fbsd_104     3054
+#define SYS_NAME_ID_amd64_fbsd_110     3040
+#define SYS_NAME_ID_amd64_fbsd_111     3041
+#define SYS_NAME_ID_amd64_fbsd_112     3042
+#define SYS_NAME_ID_amd64_fbsd_113     3043
+#define SYS_NAME_ID_amd64_fbsd_120     3060
+#define SYS_NAME_ID_amd64_fbsd_121     3061
+#define SYS_NAME_ID_amd64_fbsd_122     3062
 
 #define SYS_NAME_ID_amd64_w2k           3400
 
@@ -279,27 +381,41 @@
 #define SYS_NAME_ID_arm_linux24         3802
 #define SYS_NAME_ID_arm_linux26         3803
 
-/*
- * Placeholder to keep system-wide standard flags since this file is included by all 
- * files (i.e in afs/param.h)
- */
-#ifdef	notdef
-/* Should be enabled by src sites that are compiling afs in a kerberos environment
- * (i.e. use their headers and libs) and want to use the realm-related kerberos code
- */
-#define	AFS_ATHENA_STDENV		1
-#endif
-#ifdef	AFS_ATHENA_STDENV
-/* So that they don't get our own version of the kerb-related function  in libutil.a */
-#define	afs_krb_get_lrealm(r,n)	krb_get_lrealm(r,n)
-#define	AFS_REALM_SZ		REALM_SZ
-#endif
+#define SYS_NAME_ID_i386_dfbsd_22        3900
+#define SYS_NAME_ID_i386_dfbsd_23        3901
+#define SYS_NAME_ID_i386_dfbsd_24        3902
+#define SYS_NAME_ID_i386_dfbsd_25        3903
+#define SYS_NAME_ID_i386_dfbsd_26        3904
+#define SYS_NAME_ID_i386_dfbsd_27        3905
+
+#define SYS_NAME_ID_amd64_obsd36        4005
+#define SYS_NAME_ID_amd64_obsd37        4006
+#define SYS_NAME_ID_amd64_obsd38        4007
+#define SYS_NAME_ID_amd64_obsd39        4008
+#define SYS_NAME_ID_amd64_obsd40        4009
+#define SYS_NAME_ID_amd64_obsd41        4010
+#define SYS_NAME_ID_amd64_obsd42        4011
+#define SYS_NAME_ID_amd64_obsd43        4012
+#define SYS_NAME_ID_amd64_obsd44        4013
+#define SYS_NAME_ID_amd64_obsd45        4014
+#define SYS_NAME_ID_amd64_obsd46        4015
+#define SYS_NAME_ID_amd64_obsd47        4016
+#define SYS_NAME_ID_amd64_obsd48        4017
+#define SYS_NAME_ID_amd64_obsd49        4018
+#define SYS_NAME_ID_amd64_obsd50        4019
+#define SYS_NAME_ID_amd64_obsd51        4020
+#define SYS_NAME_ID_amd64_obsd52        4021
+#define SYS_NAME_ID_amd64_obsd53        4022
+#define SYS_NAME_ID_amd64_obsd54        4023
+
+#define SYS_NAME_ID_arm64_linux2	4100
+#define SYS_NAME_ID_arm64_linux26	4103
+
+#define SYS_NAME_ID_ppc64le_linux26	4203
+
+#define	AFS_REALM_SZ	64
+
+/* Specifies the number of equivalent local realm names */
+#define AFS_NUM_LREALMS 4
 
-/* Should be enabled by src sites that are compiling afs without the kerb headers/libs
- * but want to use the kerberos realm-related code
- */
-#define	AFS_KERBREALM_ENV	1
-#ifdef	AFS_KERBREALM_ENV
-#define	AFS_REALM_SZ		64
-#endif
 #endif /* __AFS_SYSNAMES_INCL_ENV_ */
